"""WormGearMeshAdvancedTimeSteppingAnalysisForModulation"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
    _7242,
)

_WORM_GEAR_MESH_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedTimeSteppingAnalysesForModulation",
    "WormGearMeshAdvancedTimeSteppingAnalysisForModulation",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2942, _2944, _2946
    from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
        _7218,
        _7249,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7936,
        _7939,
    )
    from mastapy._private.system_model.analyses_and_results.static_loads import _7911
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _3132,
    )
    from mastapy._private.system_model.connections_and_sockets.gears import _2589

    Self = TypeVar(
        "Self", bound="WormGearMeshAdvancedTimeSteppingAnalysisForModulation"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="WormGearMeshAdvancedTimeSteppingAnalysisForModulation._Cast_WormGearMeshAdvancedTimeSteppingAnalysisForModulation",
    )


__docformat__ = "restructuredtext en"
__all__ = ("WormGearMeshAdvancedTimeSteppingAnalysisForModulation",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_WormGearMeshAdvancedTimeSteppingAnalysisForModulation:
    """Special nested class for casting WormGearMeshAdvancedTimeSteppingAnalysisForModulation to subclasses."""

    __parent__: "WormGearMeshAdvancedTimeSteppingAnalysisForModulation"

    @property
    def gear_mesh_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7242.GearMeshAdvancedTimeSteppingAnalysisForModulation":
        return self.__parent__._cast(
            _7242.GearMeshAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def inter_mountable_component_connection_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7249.InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
            _7249,
        )

        return self.__parent__._cast(
            _7249.InterMountableComponentConnectionAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def connection_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "_7218.ConnectionAdvancedTimeSteppingAnalysisForModulation":
        from mastapy._private.system_model.analyses_and_results.advanced_time_stepping_analyses_for_modulation import (
            _7218,
        )

        return self.__parent__._cast(
            _7218.ConnectionAdvancedTimeSteppingAnalysisForModulation
        )

    @property
    def connection_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7939.ConnectionStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7939,
        )

        return self.__parent__._cast(_7939.ConnectionStaticLoadAnalysisCase)

    @property
    def connection_analysis_case(self: "CastSelf") -> "_7936.ConnectionAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7936,
        )

        return self.__parent__._cast(_7936.ConnectionAnalysisCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2942.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2942

        return self.__parent__._cast(_2942.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def worm_gear_mesh_advanced_time_stepping_analysis_for_modulation(
        self: "CastSelf",
    ) -> "WormGearMeshAdvancedTimeSteppingAnalysisForModulation":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class WormGearMeshAdvancedTimeSteppingAnalysisForModulation(
    _7242.GearMeshAdvancedTimeSteppingAnalysisForModulation
):
    """WormGearMeshAdvancedTimeSteppingAnalysisForModulation

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _WORM_GEAR_MESH_ADVANCED_TIME_STEPPING_ANALYSIS_FOR_MODULATION
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def connection_design(self: "Self") -> "_2589.WormGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.WormGearMesh

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_load_case(self: "Self") -> "_7911.WormGearMeshLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.WormGearMeshLoadCase

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionLoadCase")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def system_deflection_results(self: "Self") -> "_3132.WormGearMeshSystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.WormGearMeshSystemDeflection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SystemDeflectionResults")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_WormGearMeshAdvancedTimeSteppingAnalysisForModulation":
        """Cast to another type.

        Returns:
            _Cast_WormGearMeshAdvancedTimeSteppingAnalysisForModulation
        """
        return _Cast_WormGearMeshAdvancedTimeSteppingAnalysisForModulation(self)



"""PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.gears.rating.cylindrical.plastic_vdi2736 import _604

_PLASTIC_VDI2736_GEAR_SINGLE_FLANK_RATING_IN_A_METAL_PLASTIC_OR_A_PLASTIC_METAL_MESH = (
    python_net_import(
        "SMT.MastaAPI.Gears.Rating.Cylindrical.PlasticVDI2736",
        "PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh",
    )
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.rating import _477
    from mastapy._private.gears.rating.cylindrical import _578
    from mastapy._private.gears.rating.cylindrical.iso6336 import _630

    Self = TypeVar(
        "Self",
        bound="PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh",
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh._Cast_PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh",
    )


__docformat__ = "restructuredtext en"
__all__ = ("PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh:
    """Special nested class for casting PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh to subclasses."""

    __parent__: "PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh"

    @property
    def plastic_gear_vdi2736_abstract_gear_single_flank_rating(
        self: "CastSelf",
    ) -> "_604.PlasticGearVDI2736AbstractGearSingleFlankRating":
        return self.__parent__._cast(
            _604.PlasticGearVDI2736AbstractGearSingleFlankRating
        )

    @property
    def iso6336_abstract_gear_single_flank_rating(
        self: "CastSelf",
    ) -> "_630.ISO6336AbstractGearSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _630

        return self.__parent__._cast(_630.ISO6336AbstractGearSingleFlankRating)

    @property
    def cylindrical_gear_single_flank_rating(
        self: "CastSelf",
    ) -> "_578.CylindricalGearSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical import _578

        return self.__parent__._cast(_578.CylindricalGearSingleFlankRating)

    @property
    def gear_single_flank_rating(self: "CastSelf") -> "_477.GearSingleFlankRating":
        from mastapy._private.gears.rating import _477

        return self.__parent__._cast(_477.GearSingleFlankRating)

    @property
    def plastic_vdi2736_gear_single_flank_rating_in_a_metal_plastic_or_a_plastic_metal_mesh(
        self: "CastSelf",
    ) -> "PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh(
    _604.PlasticGearVDI2736AbstractGearSingleFlankRating
):
    """PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _PLASTIC_VDI2736_GEAR_SINGLE_FLANK_RATING_IN_A_METAL_PLASTIC_OR_A_PLASTIC_METAL_MESH
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh":
        """Cast to another type.

        Returns:
            _Cast_PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh
        """
        return (
            _Cast_PlasticVDI2736GearSingleFlankRatingInAMetalPlasticOrAPlasticMetalMesh(
                self
            )
        )



"""CylindricalGearGeometricEntityDrawStyle"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.system_model.analyses_and_results.power_flows import _4439

_CYLINDRICAL_GEAR_GEOMETRIC_ENTITY_DRAW_STYLE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows",
    "CylindricalGearGeometricEntityDrawStyle",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.geometry import _413, _414

    Self = TypeVar("Self", bound="CylindricalGearGeometricEntityDrawStyle")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearGeometricEntityDrawStyle._Cast_CylindricalGearGeometricEntityDrawStyle",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearGeometricEntityDrawStyle",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearGeometricEntityDrawStyle:
    """Special nested class for casting CylindricalGearGeometricEntityDrawStyle to subclasses."""

    __parent__: "CylindricalGearGeometricEntityDrawStyle"

    @property
    def power_flow_draw_style(self: "CastSelf") -> "_4439.PowerFlowDrawStyle":
        return self.__parent__._cast(_4439.PowerFlowDrawStyle)

    @property
    def draw_style(self: "CastSelf") -> "_413.DrawStyle":
        from mastapy._private.geometry import _413

        return self.__parent__._cast(_413.DrawStyle)

    @property
    def draw_style_base(self: "CastSelf") -> "_414.DrawStyleBase":
        from mastapy._private.geometry import _414

        return self.__parent__._cast(_414.DrawStyleBase)

    @property
    def cylindrical_gear_geometric_entity_draw_style(
        self: "CastSelf",
    ) -> "CylindricalGearGeometricEntityDrawStyle":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CylindricalGearGeometricEntityDrawStyle(_4439.PowerFlowDrawStyle):
    """CylindricalGearGeometricEntityDrawStyle

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_GEOMETRIC_ENTITY_DRAW_STYLE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearGeometricEntityDrawStyle":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearGeometricEntityDrawStyle
        """
        return _Cast_CylindricalGearGeometricEntityDrawStyle(self)



"""HertzianContactDeflectionCalculationMethod"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_HERTZIAN_CONTACT_DEFLECTION_CALCULATION_METHOD = python_net_import(
    "SMT.MastaAPI.MathUtility.HertzianContact",
    "HertzianContactDeflectionCalculationMethod",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="HertzianContactDeflectionCalculationMethod")
    CastSelf = TypeVar(
        "CastSelf",
        bound="HertzianContactDeflectionCalculationMethod._Cast_HertzianContactDeflectionCalculationMethod",
    )


__docformat__ = "restructuredtext en"
__all__ = ("HertzianContactDeflectionCalculationMethod",)


class HertzianContactDeflectionCalculationMethod(Enum):
    """HertzianContactDeflectionCalculationMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _HERTZIAN_CONTACT_DEFLECTION_CALCULATION_METHOD

    WEBER = 0
    SIMPLIFIED_WEBER = 1
    HOUPERT_VERSION_1 = 2
    HOUPERT_VERSION_2 = 3
    PALMGREN = 4
    MODIFIED_PALMGREN = 5
    LI = 6
    TRIPP = 7
    UMEZAWA = 8


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


HertzianContactDeflectionCalculationMethod.__setattr__ = __enum_setattr
HertzianContactDeflectionCalculationMethod.__delattr__ = __enum_delattr



"""This module holds utility classes and methods to be used internally by mastapy.

These should not be accessed by package users.
"""

from __future__ import annotations

import contextlib
import inspect
import re
from functools import lru_cache
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from re import Pattern
    from typing import Any, Type, TypeVar

    Self_StrEnum = TypeVar("Self_StrEnum", "StrEnum")

try:
    from enum import StrEnum
except ImportError:
    from enum import Enum

    class StrEnum(str, Enum):
        """Polyfill for Python 3.11+ StrEnum."""

        def __str__(self: "Self_StrEnum") -> str:
            """Override of the str magic method.

            Returns:
                str
            """
            return str(self.value)


class Setter:
    """Decorator class for setter-only properties.

    By using this instead of @property and @func.setter for setter-only properties,
    we remove some minor overheads.

    Args:
        func: the function to be decorated.
        doc (str, optional): documentation for the setter.


    Attributes:
        func: the decorated function.
    """

    def __init__(self, func, doc=None):
        self.func = func
        self.__doc__ = doc if doc is not None else func.__doc__

    def __set__(self, obj, value):
        """Override of the set magic method."""
        return self.func(obj, value)


__SYSTEM_DRAWING_COMMON = {
    "FxResources.System.Drawing.Common.SR",
    "System.LocalAppContextSwitches",
    "System.SR",
    "System.Drawing.Bitmap",
    "System.Drawing.BitmapSelector",
    "System.Drawing.BitmapSuffixInSameAssemblyAttribute",
    "System.Drawing.BitmapSuffixInSatelliteAssemblyAttribute",
    "System.Drawing.Brush",
    "System.Drawing.Brushes",
    "System.Drawing.BufferedGraphics",
    "System.Drawing.BufferedGraphicsContext",
    "System.Drawing.BufferedGraphicsManager",
    "System.Drawing.CharacterRange",
    "System.Drawing.ClientUtils",
    "System.Drawing.ContentAlignment",
    "System.Drawing.CopyPixelOperation",
    "System.Drawing.DrawingCom",
    "System.Drawing.Font",
    "System.Drawing.FontConverter",
    "System.Drawing.FontFamily",
    "System.Drawing.FontStyle",
    "System.Drawing.Graphics",
    "System.Drawing.GraphicsContext",
    "System.Drawing.GraphicsUnit",
    "System.Drawing.Icon",
    "System.Drawing.IconConverter",
    "System.Drawing.IDeviceContext",
    "System.Drawing.Image",
    "System.Drawing.ImageAnimator",
    "System.Drawing.ImageConverter",
    "System.Drawing.ImageFormatConverter",
    "System.Drawing.ImageType",
    "System.Drawing.NativeMethods",
    "System.Drawing.NumericsExtensions",
    "System.Drawing.Pen",
    "System.Drawing.Pens",
    "System.Drawing.PrintPreviewGraphics",
    "System.Drawing.Region",
    "System.Drawing.RotateFlipType",
    "System.Drawing.SafeNativeMethods",
    "System.Drawing.ScreenDC",
    "System.Drawing.SolidBrush",
    "System.Drawing.SRDescriptionAttribute",
    "System.Drawing.StockIconId",
    "System.Drawing.StockIconOptions",
    "System.Drawing.StringAlignment",
    "System.Drawing.StringDigitSubstitute",
    "System.Drawing.StringFormat",
    "System.Drawing.StringFormatFlags",
    "System.Drawing.StringTrimming",
    "System.Drawing.StringUnit",
    "System.Drawing.SystemBrushes",
    "System.Drawing.SystemFonts",
    "System.Drawing.SystemIcons",
    "System.Drawing.SystemPens",
    "System.Drawing.TextureBrush",
    "System.Drawing.ToolboxBitmapAttribute",
    "System.Drawing.Design.CategoryNameCollection",
    "System.Drawing.Drawing2D.AdjustableArrowCap",
    "System.Drawing.Drawing2D.Blend",
    "System.Drawing.Drawing2D.BrushType",
    "System.Drawing.Drawing2D.ColorBlend",
    "System.Drawing.Drawing2D.CombineMode",
    "System.Drawing.Drawing2D.CompositingMode",
    "System.Drawing.Drawing2D.CompositingQuality",
    "System.Drawing.Drawing2D.CoordinateSpace",
    "System.Drawing.Drawing2D.CustomLineCap",
    "System.Drawing.Drawing2D.CustomLineCapType",
    "System.Drawing.Drawing2D.DashCap",
    "System.Drawing.Drawing2D.DashStyle",
    "System.Drawing.Drawing2D.FillMode",
    "System.Drawing.Drawing2D.FlushIntention",
    "System.Drawing.Drawing2D.GraphicsContainer",
    "System.Drawing.Drawing2D.GraphicsPath",
    "System.Drawing.Drawing2D.GraphicsPathIterator",
    "System.Drawing.Drawing2D.GraphicsState",
    "System.Drawing.Drawing2D.HatchBrush",
    "System.Drawing.Drawing2D.HatchStyle",
    "System.Drawing.Drawing2D.InterpolationMode",
    "System.Drawing.Drawing2D.LinearGradientBrush",
    "System.Drawing.Drawing2D.LinearGradientMode",
    "System.Drawing.Drawing2D.LineCap",
    "System.Drawing.Drawing2D.LineJoin",
    "System.Drawing.Drawing2D.Matrix",
    "System.Drawing.Drawing2D.MatrixOrder",
    "System.Drawing.Drawing2D.PathData",
    "System.Drawing.Drawing2D.PathGradientBrush",
    "System.Drawing.Drawing2D.PathPointType",
    "System.Drawing.Drawing2D.PenAlignment",
    "System.Drawing.Drawing2D.PenType",
    "System.Drawing.Drawing2D.PixelOffsetMode",
    "System.Drawing.Drawing2D.QualityMode",
    "System.Drawing.Drawing2D.RegionData",
    "System.Drawing.Drawing2D.SafeCustomLineCapHandle",
    "System.Drawing.Drawing2D.SmoothingMode",
    "System.Drawing.Drawing2D.WarpMode",
    "System.Drawing.Drawing2D.WrapMode",
    "System.Drawing.Imaging.BitmapData",
    "System.Drawing.Imaging.CachedBitmap",
    "System.Drawing.Imaging.ColorAdjustType",
    "System.Drawing.Imaging.ColorChannelFlag",
    "System.Drawing.Imaging.ColorMap",
    "System.Drawing.Imaging.ColorMapType",
    "System.Drawing.Imaging.ColorMatrix",
    "System.Drawing.Imaging.ColorMatrixFlag",
    "System.Drawing.Imaging.ColorMode",
    "System.Drawing.Imaging.ColorPalette",
    "System.Drawing.Imaging.EmfPlusFlags",
    "System.Drawing.Imaging.EmfPlusRecordType",
    "System.Drawing.Imaging.EmfType",
    "System.Drawing.Imaging.Encoder",
    "System.Drawing.Imaging.EncoderParameter",
    "System.Drawing.Imaging.EncoderParameterNative",
    "System.Drawing.Imaging.EncoderParameters",
    "System.Drawing.Imaging.EncoderParametersNative",
    "System.Drawing.Imaging.EncoderParameterValueType",
    "System.Drawing.Imaging.EncoderValue",
    "System.Drawing.Imaging.FrameDimension",
    "System.Drawing.Imaging.ImageAttributes",
    "System.Drawing.Imaging.ImageCodecFlags",
    "System.Drawing.Imaging.ImageCodecInfo",
    "System.Drawing.Imaging.ImageCodecInfoPrivate",
    "System.Drawing.Imaging.ImageFlags",
    "System.Drawing.Imaging.ImageFormat",
    "System.Drawing.Imaging.ImageLockMode",
    "System.Drawing.Imaging.Metafile",
    "System.Drawing.Imaging.MetafileFrameUnit",
    "System.Drawing.Imaging.MetafileHeader",
    "System.Drawing.Imaging.MetafileHeaderEmf",
    "System.Drawing.Imaging.MetafileHeaderWmf",
    "System.Drawing.Imaging.MetafileType",
    "System.Drawing.Imaging.MetaHeader",
    "System.Drawing.Imaging.PaletteFlags",
    "System.Drawing.Imaging.PixelFormat",
    "System.Drawing.Imaging.PlayRecordCallback",
    "System.Drawing.Imaging.PropertyItem",
    "System.Drawing.Imaging.PropertyItemInternal",
    "System.Drawing.Imaging.WmfMetaHeader",
    "System.Drawing.Imaging.WmfPlaceableFileHeader",
    "System.Drawing.Internal.ApplyGraphicsProperties",
    "System.Drawing.Internal.DbgUtil",
    "System.Drawing.Internal.DeviceContext",
    "System.Drawing.Internal.DeviceContexts",
    "System.Drawing.Internal.DeviceContextType",
    "System.Drawing.Internal.GpPathData",
    "System.Drawing.Internal.GPStream",
    "System.Drawing.Internal.ISystemColorTracker",
    "System.Drawing.Internal.SystemColorTracker",
    "System.Drawing.Internal.WindowsGraphics",
    "System.Drawing.Internal.WindowsRegion",
    "System.Drawing.Interop.LOGFONT",
    "System.Drawing.Printing.Duplex",
    "System.Drawing.Printing.InvalidPrinterException",
    "System.Drawing.Printing.Margins",
    "System.Drawing.Printing.MarginsConverter",
    "System.Drawing.Printing.ModeField",
    "System.Drawing.Printing.PageSettings",
    "System.Drawing.Printing.PaperKind",
    "System.Drawing.Printing.PaperSize",
    "System.Drawing.Printing.PaperSource",
    "System.Drawing.Printing.PaperSourceKind",
    "System.Drawing.Printing.PreviewPageInfo",
    "System.Drawing.Printing.PreviewPrintController",
    "System.Drawing.Printing.PrintAction",
    "System.Drawing.Printing.PrintController",
    "System.Drawing.Printing.PrintDocument",
    "System.Drawing.Printing.PrinterResolution",
    "System.Drawing.Printing.PrinterResolutionKind",
    "System.Drawing.Printing.PrinterSettings",
    "System.Drawing.Printing.PrinterUnit",
    "System.Drawing.Printing.PrinterUnitConvert",
    "System.Drawing.Printing.PrintEventArgs",
    "System.Drawing.Printing.PrintEventHandler",
    "System.Drawing.Printing.PrintPageEventArgs",
    "System.Drawing.Printing.PrintPageEventHandler",
    "System.Drawing.Printing.PrintRange",
    "System.Drawing.Printing.QueryPageSettingsEventArgs",
    "System.Drawing.Printing.QueryPageSettingsEventHandler",
    "System.Drawing.Printing.StandardPrintController",
    "System.Drawing.Printing.TriState",
    "System.Drawing.Text.FontCollection",
    "System.Drawing.Text.GenericFontFamilies",
    "System.Drawing.Text.HotkeyPrefix",
    "System.Drawing.Text.InstalledFontCollection",
    "System.Drawing.Text.PrivateFontCollection",
    "System.Drawing.Text.TextRenderingHint",
    "System.Runtime.InteropServices.Marshalling.HandleRefMarshaller",
    "System.Text.ValueStringBuilder",
    "System.Windows.Forms.DpiHelper",
}


def is_system_drawing_common_module(module_name: str) -> bool:
    """Check whether the module is part of System.Drawing.Common.

    Args:
        module_name (str): Module to check.

    Returns:
        bool
    """
    return module_name in __SYSTEM_DRAWING_COMMON


def qualname(input: "Any") -> str:
    """Safely get the qualified name of an object.

    Args:
        input (Any): Object.

    Returns:
        str
    """

    with contextlib.suppress(AttributeError):
        return input.__qualname__

    with contextlib.suppress(AttributeError):
        return input.__name__

    return str(input)


@lru_cache(maxsize=None)
def _get_snake_case_regex() -> "Pattern[str]":
    return re.compile(r"((?<=[a-z0-9])[A-Z]|(?!^)[A-Z](?=[a-z]))")


def snake(input: str) -> str:
    """Convert a string to snake case.

    Args:
        input (str): Input string to convert.

    Returns:
        str
    """
    reg = _get_snake_case_regex()
    return reg.sub(r"_\1", input).lower()


def camel_spaced(input: str) -> str:
    """Convert a string to spaced camel case.

    Args:
        input (str): Input string to convert.

    Returns:
        str
    """
    return " ".join(x.capitalize() for x in input.replace(" ", "_").split("_"))


def camel(input: str) -> str:
    """Convert a string to camel case.

    Args:
        input (str): Input string to convert.

    Returns:
        str
    """
    return "".join(x.capitalize() for x in input.replace(" ", "_").split("_"))


def camel_lower(input: str) -> str:
    """Convert a string to lower camel case.

    Args:
        input (str): Input string to convert.

    Returns:
        str
    """
    result = camel(input)
    return result[0].lower() + result[1:]


@lru_cache(maxsize=None)
def _get_punctuation_table():
    import string

    return str.maketrans(dict.fromkeys(string.punctuation))


def strip_punctuation(input: str) -> str:
    """Strip punctuation from a string.

    Args:
        input (str): Input string to strip of punctuation.

    Returns:
        str
    """
    return input.translate(_get_punctuation_table())


__issubclass = issubclass


def issubclass(value: "Any", type_: "Type[Any]") -> bool:
    """Check if a value is a subclass of another type.

    This differs to the built in issubclass method by first confirming
    whether the value is even a class.

    Args:
        value (Any): Value to check.
        type_ (Type[Any]): Type to compare against.

    Returns:
        bool
    """
    return inspect.isclass(value) and __issubclass(value, type_)



"""Bearing"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_get_with_method,
    pythonnet_property_set,
    pythonnet_property_set_with_method,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import (
    constructor,
    conversion,
    enum_with_selected_value_runtime,
    overridable_enum_runtime,
    utility,
)
from mastapy._private._internal.implicit import enum_with_selected_value, overridable
from mastapy._private.bearings import _2116
from mastapy._private.bearings.bearing_results import _2183, _2202
from mastapy._private.bearings.tolerances import _2141
from mastapy._private.materials.efficiency import _396
from mastapy._private.system_model.part_model import _2718

_DATABASE_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Databases", "DatabaseWithSelectedItem"
)
_ARRAY = python_net_import("System", "Array")
_BEARING = python_net_import("SMT.MastaAPI.SystemModel.PartModel", "Bearing")

if TYPE_CHECKING:
    from typing import Any, List, Tuple, Type, TypeVar, Union

    from mastapy._private.bearings import _2108, _2112, _2125
    from mastapy._private.bearings.bearing_designs import _2378
    from mastapy._private.bearings.bearing_results import _2201
    from mastapy._private.bearings.bearing_results.rolling import _2317
    from mastapy._private.bearings.tolerances import (
        _2142,
        _2144,
        _2145,
        _2150,
        _2151,
        _2155,
        _2158,
        _2160,
        _2162,
    )
    from mastapy._private.materials import _369
    from mastapy._private.math_utility.measured_vectors import _1781
    from mastapy._private.system_model import _2452
    from mastapy._private.system_model.part_model import (
        _2708,
        _2710,
        _2711,
        _2715,
        _2716,
        _2738,
        _2743,
        _2749,
    )
    from mastapy._private.system_model.part_model.shaft_model import _2759
    from mastapy._private.utility import _1825
    from mastapy._private.utility.report import _2015

    Self = TypeVar("Self", bound="Bearing")
    CastSelf = TypeVar("CastSelf", bound="Bearing._Cast_Bearing")


__docformat__ = "restructuredtext en"
__all__ = ("Bearing",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Bearing:
    """Special nested class for casting Bearing to subclasses."""

    __parent__: "Bearing"

    @property
    def connector(self: "CastSelf") -> "_2718.Connector":
        return self.__parent__._cast(_2718.Connector)

    @property
    def mountable_component(self: "CastSelf") -> "_2738.MountableComponent":
        from mastapy._private.system_model.part_model import _2738

        return self.__parent__._cast(_2738.MountableComponent)

    @property
    def component(self: "CastSelf") -> "_2715.Component":
        from mastapy._private.system_model.part_model import _2715

        return self.__parent__._cast(_2715.Component)

    @property
    def part(self: "CastSelf") -> "_2743.Part":
        from mastapy._private.system_model.part_model import _2743

        return self.__parent__._cast(_2743.Part)

    @property
    def design_entity(self: "CastSelf") -> "_2452.DesignEntity":
        from mastapy._private.system_model import _2452

        return self.__parent__._cast(_2452.DesignEntity)

    @property
    def bearing(self: "CastSelf") -> "Bearing":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class Bearing(_2718.Connector):
    """Bearing

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _BEARING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def axial_displacement_preload(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "AxialDisplacementPreload")

        if temp is None:
            return 0.0

        return temp

    @axial_displacement_preload.setter
    @exception_bridge
    @enforce_parameter_types
    def axial_displacement_preload(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AxialDisplacementPreload",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def axial_force_preload(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "AxialForcePreload")

        if temp is None:
            return 0.0

        return temp

    @axial_force_preload.setter
    @exception_bridge
    @enforce_parameter_types
    def axial_force_preload(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AxialForcePreload",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def axial_internal_clearance(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "AxialInternalClearance")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @axial_internal_clearance.setter
    @exception_bridge
    @enforce_parameter_types
    def axial_internal_clearance(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "AxialInternalClearance", value)

    @property
    @exception_bridge
    def axial_stiffness_at_mounting_points(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "AxialStiffnessAtMountingPoints")

        if temp is None:
            return 0.0

        return temp

    @axial_stiffness_at_mounting_points.setter
    @exception_bridge
    @enforce_parameter_types
    def axial_stiffness_at_mounting_points(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AxialStiffnessAtMountingPoints",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def bearing_life_adjustment_factor_for_operating_conditions(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(
            self.wrapped, "BearingLifeAdjustmentFactorForOperatingConditions"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @bearing_life_adjustment_factor_for_operating_conditions.setter
    @exception_bridge
    @enforce_parameter_types
    def bearing_life_adjustment_factor_for_operating_conditions(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped, "BearingLifeAdjustmentFactorForOperatingConditions", value
        )

    @property
    @exception_bridge
    def bearing_life_adjustment_factor_for_special_bearing_properties(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(
            self.wrapped, "BearingLifeAdjustmentFactorForSpecialBearingProperties"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @bearing_life_adjustment_factor_for_special_bearing_properties.setter
    @exception_bridge
    @enforce_parameter_types
    def bearing_life_adjustment_factor_for_special_bearing_properties(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped,
            "BearingLifeAdjustmentFactorForSpecialBearingProperties",
            value,
        )

    @property
    @exception_bridge
    def bearing_life_modification_factor(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "BearingLifeModificationFactor")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @bearing_life_modification_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def bearing_life_modification_factor(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "BearingLifeModificationFactor", value)

    @property
    @exception_bridge
    def bearing_tolerance_class(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_BearingToleranceClass":
        """EnumWithSelectedValue[mastapy.bearings.tolerances.BearingToleranceClass]"""
        temp = pythonnet_property_get(self.wrapped, "BearingToleranceClass")

        if temp is None:
            return None

        value = enum_with_selected_value.EnumWithSelectedValue_BearingToleranceClass.wrapped_type()
        return enum_with_selected_value_runtime.create(temp, value)

    @bearing_tolerance_class.setter
    @exception_bridge
    @enforce_parameter_types
    def bearing_tolerance_class(
        self: "Self", value: "_2141.BearingToleranceClass"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_BearingToleranceClass.implicit_type()
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        pythonnet_property_set(self.wrapped, "BearingToleranceClass", value)

    @property
    @exception_bridge
    def bearing_tolerance_definition(
        self: "Self",
    ) -> "_2142.BearingToleranceDefinitionOptions":
        """mastapy.bearings.tolerances.BearingToleranceDefinitionOptions"""
        temp = pythonnet_property_get(self.wrapped, "BearingToleranceDefinition")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Bearings.Tolerances.BearingToleranceDefinitionOptions"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings.tolerances._2142",
            "BearingToleranceDefinitionOptions",
        )(value)

    @bearing_tolerance_definition.setter
    @exception_bridge
    @enforce_parameter_types
    def bearing_tolerance_definition(
        self: "Self", value: "_2142.BearingToleranceDefinitionOptions"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Bearings.Tolerances.BearingToleranceDefinitionOptions"
        )
        pythonnet_property_set(self.wrapped, "BearingToleranceDefinition", value)

    @property
    @exception_bridge
    def coefficient_of_friction(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "CoefficientOfFriction")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @coefficient_of_friction.setter
    @exception_bridge
    @enforce_parameter_types
    def coefficient_of_friction(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "CoefficientOfFriction", value)

    @property
    @exception_bridge
    def damping_options(self: "Self") -> "_2112.BearingDampingMatrixOption":
        """mastapy.bearings.BearingDampingMatrixOption"""
        temp = pythonnet_property_get(self.wrapped, "DampingOptions")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Bearings.BearingDampingMatrixOption"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings._2112", "BearingDampingMatrixOption"
        )(value)

    @damping_options.setter
    @exception_bridge
    @enforce_parameter_types
    def damping_options(
        self: "Self", value: "_2112.BearingDampingMatrixOption"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Bearings.BearingDampingMatrixOption"
        )
        pythonnet_property_set(self.wrapped, "DampingOptions", value)

    @property
    @exception_bridge
    def diameter_of_contact_on_inner_race_at_nominal_contact_angle(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "DiameterOfContactOnInnerRaceAtNominalContactAngle"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def diameter_of_contact_on_left_race(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DiameterOfContactOnLeftRace")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def diameter_of_contact_on_outer_race_at_nominal_contact_angle(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "DiameterOfContactOnOuterRaceAtNominalContactAngle"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def diameter_of_contact_on_right_race(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DiameterOfContactOnRightRace")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def difference_between_inner_diameter_and_diameter_of_connected_component_at_inner_connection(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "DifferenceBetweenInnerDiameterAndDiameterOfConnectedComponentAtInnerConnection",
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def difference_between_outer_diameter_and_diameter_of_connected_component_at_outer_connection(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "DifferenceBetweenOuterDiameterAndDiameterOfConnectedComponentAtOuterConnection",
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def efficiency_rating_method(
        self: "Self",
    ) -> "overridable.Overridable_BearingEfficiencyRatingMethod":
        """Overridable[mastapy.materials.efficiency.BearingEfficiencyRatingMethod]"""
        temp = pythonnet_property_get(self.wrapped, "EfficiencyRatingMethod")

        if temp is None:
            return None

        value = overridable.Overridable_BearingEfficiencyRatingMethod.wrapped_type()
        return overridable_enum_runtime.create(temp, value)

    @efficiency_rating_method.setter
    @exception_bridge
    @enforce_parameter_types
    def efficiency_rating_method(
        self: "Self",
        value: "Union[_396.BearingEfficiencyRatingMethod, Tuple[_396.BearingEfficiencyRatingMethod, bool]]",
    ) -> None:
        wrapper_type = (
            overridable.Overridable_BearingEfficiencyRatingMethod.wrapper_type()
        )
        enclosed_type = (
            overridable.Overridable_BearingEfficiencyRatingMethod.implicit_type()
        )
        value, is_overridden = _unpack_overridable(value)
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](
            value if value is not None else None, is_overridden
        )
        pythonnet_property_set(self.wrapped, "EfficiencyRatingMethod", value)

    @property
    @exception_bridge
    def feed_flow_rate(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "FeedFlowRate")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @feed_flow_rate.setter
    @exception_bridge
    @enforce_parameter_types
    def feed_flow_rate(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "FeedFlowRate", value)

    @property
    @exception_bridge
    def feed_pressure(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "FeedPressure")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @feed_pressure.setter
    @exception_bridge
    @enforce_parameter_types
    def feed_pressure(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "FeedPressure", value)

    @property
    @exception_bridge
    def first_element_angle(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "FirstElementAngle")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @first_element_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def first_element_angle(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "FirstElementAngle", value)

    @property
    @exception_bridge
    def force_at_zero_displacement_input_method(
        self: "Self",
    ) -> "_2710.BearingF0InputMethod":
        """mastapy.system_model.part_model.BearingF0InputMethod"""
        temp = pythonnet_property_get(
            self.wrapped, "ForceAtZeroDisplacementInputMethod"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.SystemModel.PartModel.BearingF0InputMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.system_model.part_model._2710", "BearingF0InputMethod"
        )(value)

    @force_at_zero_displacement_input_method.setter
    @exception_bridge
    @enforce_parameter_types
    def force_at_zero_displacement_input_method(
        self: "Self", value: "_2710.BearingF0InputMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.SystemModel.PartModel.BearingF0InputMethod"
        )
        pythonnet_property_set(
            self.wrapped, "ForceAtZeroDisplacementInputMethod", value
        )

    @property
    @exception_bridge
    def has_radial_mounting_clearance(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "HasRadialMountingClearance")

        if temp is None:
            return False

        return temp

    @has_radial_mounting_clearance.setter
    @exception_bridge
    @enforce_parameter_types
    def has_radial_mounting_clearance(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "HasRadialMountingClearance",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def include_fitting_details(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IncludeFittingDetails")

        if temp is None:
            return False

        return temp

    @include_fitting_details.setter
    @exception_bridge
    @enforce_parameter_types
    def include_fitting_details(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "IncludeFittingDetails",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def inner_diameter(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "InnerDiameter")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @inner_diameter.setter
    @exception_bridge
    @enforce_parameter_types
    def inner_diameter(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "InnerDiameter", value)

    @property
    @exception_bridge
    def inner_fitting_chart(self: "Self") -> "_2015.SimpleChartDefinition":
        """mastapy.utility.report.SimpleChartDefinition

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InnerFittingChart")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def inner_node_position_from_centre(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InnerNodePositionFromCentre")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def is_internal_clearance_adjusted_after_fitting(
        self: "Self",
    ) -> "overridable.Overridable_bool":
        """Overridable[bool]"""
        temp = pythonnet_property_get(
            self.wrapped, "IsInternalClearanceAdjustedAfterFitting"
        )

        if temp is None:
            return False

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_bool"
        )(temp)

    @is_internal_clearance_adjusted_after_fitting.setter
    @exception_bridge
    @enforce_parameter_types
    def is_internal_clearance_adjusted_after_fitting(
        self: "Self", value: "Union[bool, Tuple[bool, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_bool.wrapper_type()
        enclosed_type = overridable.Overridable_bool.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else False, is_overridden
        )
        pythonnet_property_set(
            self.wrapped, "IsInternalClearanceAdjustedAfterFitting", value
        )

    @property
    @exception_bridge
    def journal_bearing_type(self: "Self") -> "_2125.JournalBearingType":
        """mastapy.bearings.JournalBearingType"""
        temp = pythonnet_property_get(self.wrapped, "JournalBearingType")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Bearings.JournalBearingType"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings._2125", "JournalBearingType"
        )(value)

    @journal_bearing_type.setter
    @exception_bridge
    @enforce_parameter_types
    def journal_bearing_type(self: "Self", value: "_2125.JournalBearingType") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Bearings.JournalBearingType"
        )
        pythonnet_property_set(self.wrapped, "JournalBearingType", value)

    @property
    @exception_bridge
    def left_node_position_from_centre(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LeftNodePositionFromCentre")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def length(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "Length")

        if temp is None:
            return 0.0

        return temp

    @length.setter
    @exception_bridge
    @enforce_parameter_types
    def length(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "Length", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def lubrication_detail(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get_with_method(
            self.wrapped, "LubricationDetail", "SelectedItemName"
        )

        if temp is None:
            return ""

        return temp

    @lubrication_detail.setter
    @exception_bridge
    @enforce_parameter_types
    def lubrication_detail(self: "Self", value: "str") -> None:
        pythonnet_property_set_with_method(
            self.wrapped,
            "LubricationDetail",
            "SetSelectedItem",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def maximum_bearing_life_modification_factor(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(
            self.wrapped, "MaximumBearingLifeModificationFactor"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @maximum_bearing_life_modification_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def maximum_bearing_life_modification_factor(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped, "MaximumBearingLifeModificationFactor", value
        )

    @property
    @exception_bridge
    def model(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_BearingModel":
        """EnumWithSelectedValue[mastapy.bearings.BearingModel]"""
        temp = pythonnet_property_get(self.wrapped, "Model")

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_BearingModel.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @model.setter
    @exception_bridge
    @enforce_parameter_types
    def model(self: "Self", value: "_2116.BearingModel") -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_BearingModel.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        pythonnet_property_set(self.wrapped, "Model", value)

    @property
    @exception_bridge
    def offset_of_contact_on_inner_race_at_nominal_contact_angle(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "OffsetOfContactOnInnerRaceAtNominalContactAngle"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def offset_of_contact_on_left_race(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OffsetOfContactOnLeftRace")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def offset_of_contact_on_outer_race_at_nominal_contact_angle(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "OffsetOfContactOnOuterRaceAtNominalContactAngle"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def offset_of_contact_on_right_race(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OffsetOfContactOnRightRace")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def orientation(self: "Self") -> "_2201.Orientations":
        """mastapy.bearings.bearing_results.Orientations"""
        temp = pythonnet_property_get(self.wrapped, "Orientation")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Bearings.BearingResults.Orientations"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings.bearing_results._2201", "Orientations"
        )(value)

    @orientation.setter
    @exception_bridge
    @enforce_parameter_types
    def orientation(self: "Self", value: "_2201.Orientations") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Bearings.BearingResults.Orientations"
        )
        pythonnet_property_set(self.wrapped, "Orientation", value)

    @property
    @exception_bridge
    def outer_diameter(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "OuterDiameter")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @outer_diameter.setter
    @exception_bridge
    @enforce_parameter_types
    def outer_diameter(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "OuterDiameter", value)

    @property
    @exception_bridge
    def outer_fitting_chart(self: "Self") -> "_2015.SimpleChartDefinition":
        """mastapy.utility.report.SimpleChartDefinition

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OuterFittingChart")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def outer_node_position_from_centre(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OuterNodePositionFromCentre")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def override_design_lubrication_detail(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "OverrideDesignLubricationDetail")

        if temp is None:
            return False

        return temp

    @override_design_lubrication_detail.setter
    @exception_bridge
    @enforce_parameter_types
    def override_design_lubrication_detail(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "OverrideDesignLubricationDetail",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def percentage_difference_between_inner_diameter_and_diameter_of_connected_component_at_inner_connection(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "PercentageDifferenceBetweenInnerDiameterAndDiameterOfConnectedComponentAtInnerConnection",
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def percentage_difference_between_outer_diameter_and_diameter_of_connected_component_at_outer_connection(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "PercentageDifferenceBetweenOuterDiameterAndDiameterOfConnectedComponentAtOuterConnection",
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def permissible_axial_load_calculation_method(
        self: "Self",
    ) -> "overridable.Overridable_CylindricalRollerMaxAxialLoadMethod":
        """Overridable[mastapy.bearings.bearing_results.CylindricalRollerMaxAxialLoadMethod]"""
        temp = pythonnet_property_get(
            self.wrapped, "PermissibleAxialLoadCalculationMethod"
        )

        if temp is None:
            return None

        value = (
            overridable.Overridable_CylindricalRollerMaxAxialLoadMethod.wrapped_type()
        )
        return overridable_enum_runtime.create(temp, value)

    @permissible_axial_load_calculation_method.setter
    @exception_bridge
    @enforce_parameter_types
    def permissible_axial_load_calculation_method(
        self: "Self",
        value: "Union[_2183.CylindricalRollerMaxAxialLoadMethod, Tuple[_2183.CylindricalRollerMaxAxialLoadMethod, bool]]",
    ) -> None:
        wrapper_type = (
            overridable.Overridable_CylindricalRollerMaxAxialLoadMethod.wrapper_type()
        )
        enclosed_type = (
            overridable.Overridable_CylindricalRollerMaxAxialLoadMethod.implicit_type()
        )
        value, is_overridden = _unpack_overridable(value)
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](
            value if value is not None else None, is_overridden
        )
        pythonnet_property_set(
            self.wrapped, "PermissibleAxialLoadCalculationMethod", value
        )

    @property
    @exception_bridge
    def permissible_track_truncation(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "PermissibleTrackTruncation")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @permissible_track_truncation.setter
    @exception_bridge
    @enforce_parameter_types
    def permissible_track_truncation(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "PermissibleTrackTruncation", value)

    @property
    @exception_bridge
    def preload(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_PreloadType":
        """EnumWithSelectedValue[mastapy.bearings.bearing_results.PreloadType]"""
        temp = pythonnet_property_get(self.wrapped, "Preload")

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_PreloadType.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @preload.setter
    @exception_bridge
    @enforce_parameter_types
    def preload(self: "Self", value: "_2202.PreloadType") -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_PreloadType.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        pythonnet_property_set(self.wrapped, "Preload", value)

    @property
    @exception_bridge
    def preload_spring_initial_compression(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PreloadSpringInitialCompression")

        if temp is None:
            return 0.0

        return temp

    @preload_spring_initial_compression.setter
    @exception_bridge
    @enforce_parameter_types
    def preload_spring_initial_compression(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "PreloadSpringInitialCompression",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def preload_spring_max_travel(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PreloadSpringMaxTravel")

        if temp is None:
            return 0.0

        return temp

    @preload_spring_max_travel.setter
    @exception_bridge
    @enforce_parameter_types
    def preload_spring_max_travel(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "PreloadSpringMaxTravel",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def preload_spring_stiffness(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PreloadSpringStiffness")

        if temp is None:
            return 0.0

        return temp

    @preload_spring_stiffness.setter
    @exception_bridge
    @enforce_parameter_types
    def preload_spring_stiffness(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "PreloadSpringStiffness",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def preload_spring_on_outer(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "PreloadSpringOnOuter")

        if temp is None:
            return False

        return temp

    @preload_spring_on_outer.setter
    @exception_bridge
    @enforce_parameter_types
    def preload_spring_on_outer(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "PreloadSpringOnOuter",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def preload_is_from_left(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "PreloadIsFromLeft")

        if temp is None:
            return False

        return temp

    @preload_is_from_left.setter
    @exception_bridge
    @enforce_parameter_types
    def preload_is_from_left(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "PreloadIsFromLeft",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def radial_internal_clearance(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "RadialInternalClearance")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @radial_internal_clearance.setter
    @exception_bridge
    @enforce_parameter_types
    def radial_internal_clearance(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "RadialInternalClearance", value)

    @property
    @exception_bridge
    def right_node_position_from_centre(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RightNodePositionFromCentre")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def system_includes_oil_pump(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SystemIncludesOilPump")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def use_design_iso14179_settings(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseDesignISO14179Settings")

        if temp is None:
            return False

        return temp

    @use_design_iso14179_settings.setter
    @exception_bridge
    @enforce_parameter_types
    def use_design_iso14179_settings(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseDesignISO14179Settings",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def axial_internal_clearance_tolerance(
        self: "Self",
    ) -> "_2708.AxialInternalClearanceTolerance":
        """mastapy.system_model.part_model.AxialInternalClearanceTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AxialInternalClearanceTolerance")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def detail(self: "Self") -> "_2378.BearingDesign":
        """mastapy.bearings.bearing_designs.BearingDesign

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Detail")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def displacement_for_stiffness_operating_point(
        self: "Self",
    ) -> "_1781.VectorWithLinearAndAngularComponents":
        """mastapy.math_utility.measured_vectors.VectorWithLinearAndAngularComponents

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "DisplacementForStiffnessOperatingPoint"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def force_at_zero_displacement(
        self: "Self",
    ) -> "_1781.VectorWithLinearAndAngularComponents":
        """mastapy.math_utility.measured_vectors.VectorWithLinearAndAngularComponents

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ForceAtZeroDisplacement")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def force_for_stiffness_operating_point(
        self: "Self",
    ) -> "_1781.VectorWithLinearAndAngularComponents":
        """mastapy.math_utility.measured_vectors.VectorWithLinearAndAngularComponents

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ForceForStiffnessOperatingPoint")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def friction_coefficients(
        self: "Self",
    ) -> "_2317.RollingBearingFrictionCoefficients":
        """mastapy.bearings.bearing_results.rolling.RollingBearingFrictionCoefficients

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FrictionCoefficients")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def inner_mounting_sleeve_inner_diameter_tolerance(
        self: "Self",
    ) -> "_2151.OuterSupportTolerance":
        """mastapy.bearings.tolerances.OuterSupportTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "InnerMountingSleeveInnerDiameterTolerance"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def inner_mounting_sleeve_outer_diameter_tolerance(
        self: "Self",
    ) -> "_2145.InnerSupportTolerance":
        """mastapy.bearings.tolerances.InnerSupportTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "InnerMountingSleeveOuterDiameterTolerance"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def inner_support_detail(self: "Self") -> "_2158.SupportDetail":
        """mastapy.bearings.tolerances.SupportDetail

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InnerSupportDetail")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def left_support_detail(self: "Self") -> "_2158.SupportDetail":
        """mastapy.bearings.tolerances.SupportDetail

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LeftSupportDetail")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def outer_mounting_sleeve_inner_diameter_tolerance(
        self: "Self",
    ) -> "_2151.OuterSupportTolerance":
        """mastapy.bearings.tolerances.OuterSupportTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "OuterMountingSleeveInnerDiameterTolerance"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def outer_mounting_sleeve_outer_diameter_tolerance(
        self: "Self",
    ) -> "_2145.InnerSupportTolerance":
        """mastapy.bearings.tolerances.InnerSupportTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "OuterMountingSleeveOuterDiameterTolerance"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def outer_support_detail(self: "Self") -> "_2158.SupportDetail":
        """mastapy.bearings.tolerances.SupportDetail

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OuterSupportDetail")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def overridden_lubrication_detail(self: "Self") -> "_369.LubricationDetail":
        """mastapy.materials.LubricationDetail

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "OverriddenLubricationDetail")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def radial_internal_clearance_tolerance(
        self: "Self",
    ) -> "_2749.RadialInternalClearanceTolerance":
        """mastapy.system_model.part_model.RadialInternalClearanceTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RadialInternalClearanceTolerance")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def right_support_detail(self: "Self") -> "_2158.SupportDetail":
        """mastapy.bearings.tolerances.SupportDetail

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RightSupportDetail")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def ring_tolerance_inner(self: "Self") -> "_2144.InnerRingTolerance":
        """mastapy.bearings.tolerances.InnerRingTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RingToleranceInner")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def ring_tolerance_left(self: "Self") -> "_2155.RingTolerance":
        """mastapy.bearings.tolerances.RingTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RingToleranceLeft")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def ring_tolerance_outer(self: "Self") -> "_2150.OuterRingTolerance":
        """mastapy.bearings.tolerances.OuterRingTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RingToleranceOuter")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def ring_tolerance_right(self: "Self") -> "_2155.RingTolerance":
        """mastapy.bearings.tolerances.RingTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RingToleranceRight")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def skf_loss_moment_multipliers(self: "Self") -> "_1825.SKFLossMomentMultipliers":
        """mastapy.utility.SKFLossMomentMultipliers

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SKFLossMomentMultipliers")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def simple_bearing_detail_property(self: "Self") -> "_2378.BearingDesign":
        """mastapy.bearings.bearing_designs.BearingDesign

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SimpleBearingDetailProperty")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def support_tolerance_inner(self: "Self") -> "_2145.InnerSupportTolerance":
        """mastapy.bearings.tolerances.InnerSupportTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SupportToleranceInner")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def support_tolerance_left(self: "Self") -> "_2160.SupportTolerance":
        """mastapy.bearings.tolerances.SupportTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SupportToleranceLeft")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def support_tolerance_outer(self: "Self") -> "_2151.OuterSupportTolerance":
        """mastapy.bearings.tolerances.OuterSupportTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SupportToleranceOuter")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def support_tolerance_right(self: "Self") -> "_2160.SupportTolerance":
        """mastapy.bearings.tolerances.SupportTolerance

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SupportToleranceRight")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def mounting(self: "Self") -> "List[_2711.BearingRaceMountingOptions]":
        """List[mastapy.system_model.part_model.BearingRaceMountingOptions]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Mounting")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def tolerance_combinations(self: "Self") -> "List[_2162.ToleranceCombination]":
        """List[mastapy.bearings.tolerances.ToleranceCombination]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ToleranceCombinations")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def is_radial_bearing(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsRadialBearing")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def specified_stiffness_for_linear_bearing_in_local_coordinate_system(
        self: "Self",
    ) -> "List[List[float]]":
        """List[List[float]]"""
        temp = pythonnet_property_get(
            self.wrapped, "SpecifiedStiffnessForLinearBearingInLocalCoordinateSystem"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_list_float_2d(temp)

        if value is None:
            return None

        return value

    @specified_stiffness_for_linear_bearing_in_local_coordinate_system.setter
    @exception_bridge
    @enforce_parameter_types
    def specified_stiffness_for_linear_bearing_in_local_coordinate_system(
        self: "Self", value: "List[List[float]]"
    ) -> None:
        value = conversion.mp_to_pn_list_float_2d(value)
        pythonnet_property_set(
            self.wrapped,
            "SpecifiedStiffnessForLinearBearingInLocalCoordinateSystem",
            value,
        )

    @exception_bridge
    @enforce_parameter_types
    def try_attach_right_side_to(
        self: "Self", shaft: "_2759.Shaft", offset: "float" = float("nan")
    ) -> "_2716.ComponentsConnectedResult":
        """mastapy.system_model.part_model.ComponentsConnectedResult

        Args:
            shaft (mastapy.system_model.part_model.shaft_model.Shaft)
            offset (float, optional)
        """
        offset = float(offset)
        method_result = pythonnet_method_call(
            self.wrapped,
            "TryAttachRightSideTo",
            shaft.wrapped if shaft else None,
            offset if offset else 0.0,
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @exception_bridge
    @enforce_parameter_types
    def set_detail_from_catalogue(
        self: "Self", catalogue: "_2108.BearingCatalog", designation: "str"
    ) -> None:
        """Method does not return.

        Args:
            catalogue (mastapy.bearings.BearingCatalog)
            designation (str)
        """
        catalogue = conversion.mp_to_pn_enum(
            catalogue, "SMT.MastaAPI.Bearings.BearingCatalog"
        )
        designation = str(designation)
        pythonnet_method_call(
            self.wrapped,
            "SetDetailFromCatalogue",
            catalogue,
            designation if designation else "",
        )

    @exception_bridge
    @enforce_parameter_types
    def try_attach_left_side_to(
        self: "Self", shaft: "_2759.Shaft", offset: "float" = float("nan")
    ) -> "_2716.ComponentsConnectedResult":
        """mastapy.system_model.part_model.ComponentsConnectedResult

        Args:
            shaft (mastapy.system_model.part_model.shaft_model.Shaft)
            offset (float, optional)
        """
        offset = float(offset)
        method_result = pythonnet_method_call(
            self.wrapped,
            "TryAttachLeftSideTo",
            shaft.wrapped if shaft else None,
            offset if offset else 0.0,
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @property
    def cast_to(self: "Self") -> "_Cast_Bearing":
        """Cast to another type.

        Returns:
            _Cast_Bearing
        """
        return _Cast_Bearing(self)



"""TaskProgress"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.class_property import classproperty
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_method_call_overload,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _7951
from mastapy._private._internal import constructor, conversion, utility

_STRING = python_net_import("System", "String")
_ACTION = python_net_import("System", "Action")
_TASK_PROGRESS = python_net_import("SMT.MastaAPIUtility", "TaskProgress")

if TYPE_CHECKING:
    from typing import Any, Callable, Iterable, List, Type, TypeVar

    from mastapy._private import _7958

    Self = TypeVar("Self", bound="TaskProgress")
    CastSelf = TypeVar("CastSelf", bound="TaskProgress._Cast_TaskProgress")


__docformat__ = "restructuredtext en"
__all__ = ("TaskProgress",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_TaskProgress:
    """Special nested class for casting TaskProgress to subclasses."""

    __parent__: "TaskProgress"

    @property
    def task_progress(self: "CastSelf") -> "TaskProgress":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class TaskProgress(_7951.MarshalByRefObjectPermanent):
    """TaskProgress

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TASK_PROGRESS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def title(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Title")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def status_no_eta(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "StatusNoEta")

        if temp is None:
            return ""

        return temp

    @status_no_eta.setter
    @exception_bridge
    @enforce_parameter_types
    def status_no_eta(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "StatusNoEta", str(value) if value is not None else ""
        )

    @property
    @exception_bridge
    def status(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "Status")

        if temp is None:
            return ""

        return temp

    @status.setter
    @exception_bridge
    @enforce_parameter_types
    def status(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "Status", str(value) if value is not None else ""
        )

    @property
    @exception_bridge
    def number_of_items(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfItems")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def show_progress(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowProgress")

        if temp is None:
            return False

        return temp

    @show_progress.setter
    @exception_bridge
    @enforce_parameter_types
    def show_progress(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "ShowProgress", bool(value) if value is not None else False
        )

    @property
    @exception_bridge
    def show_completion_status(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowCompletionStatus")

        if temp is None:
            return False

        return temp

    @show_completion_status.setter
    @exception_bridge
    @enforce_parameter_types
    def show_completion_status(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowCompletionStatus",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def can_cancel(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "CanCancel")

        if temp is None:
            return False

        return temp

    @can_cancel.setter
    @exception_bridge
    @enforce_parameter_types
    def can_cancel(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "CanCancel", bool(value) if value is not None else False
        )

    @property
    @exception_bridge
    def additional_string_to_add_to_title(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "AdditionalStringToAddToTitle")

        if temp is None:
            return ""

        return temp

    @additional_string_to_add_to_title.setter
    @exception_bridge
    @enforce_parameter_types
    def additional_string_to_add_to_title(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AdditionalStringToAddToTitle",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def is_progress_tree_cell_expanded(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IsProgressTreeCellExpanded")

        if temp is None:
            return False

        return temp

    @is_progress_tree_cell_expanded.setter
    @exception_bridge
    @enforce_parameter_types
    def is_progress_tree_cell_expanded(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "IsProgressTreeCellExpanded",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def parent(self: "Self") -> "TaskProgress":
        """mastapy.TaskProgress

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Parent")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @classproperty
    @exception_bridge
    def null_task_progress(cls) -> "TaskProgress":
        """mastapy.TaskProgress"""
        temp = pythonnet_property_get(TaskProgress.TYPE, "NullTaskProgress")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @classproperty
    @exception_bridge
    def null(cls) -> "TaskProgress":
        """mastapy.TaskProgress"""
        temp = pythonnet_property_get(TaskProgress.TYPE, "Null")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def child_tasks(self: "Self") -> "List[TaskProgress]":
        """List[mastapy.TaskProgress]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ChildTasks")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def is_aborting(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsAborting")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def fraction_complete(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "FractionComplete")

        if temp is None:
            return 0.0

        return temp

    @fraction_complete.setter
    @exception_bridge
    @enforce_parameter_types
    def fraction_complete(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "FractionComplete", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def additional_status_string(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "AdditionalStatusString")

        if temp is None:
            return ""

        return temp

    @additional_status_string.setter
    @exception_bridge
    @enforce_parameter_types
    def additional_status_string(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AdditionalStatusString",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def root_task_progress(self: "Self") -> "TaskProgress":
        """mastapy.TaskProgress

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RootTaskProgress")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def is_root_task_progress(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsRootTaskProgress")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def is_leaf(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsLeaf")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def is_complete(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IsComplete")

        if temp is None:
            return False

        return temp

    @exception_bridge
    @enforce_parameter_types
    def add_progress_status_updated(
        self: "Self", value: "Callable[[str], None]"
    ) -> None:
        """Method does not return.

        Args:
            value (Callable[[str], None])
        """
        pythonnet_method_call(self.wrapped, "add_ProgressStatusUpdated", value)

    @exception_bridge
    @enforce_parameter_types
    def remove_progress_status_updated(
        self: "Self", value: "Callable[[str], None]"
    ) -> None:
        """Method does not return.

        Args:
            value (Callable[[str], None])
        """
        pythonnet_method_call(self.wrapped, "remove_ProgressStatusUpdated", value)

    @exception_bridge
    @enforce_parameter_types
    def add_progress_incremented(
        self: "Self", value: "Callable[[float], None]"
    ) -> None:
        """Method does not return.

        Args:
            value (Callable[[float], None])
        """
        pythonnet_method_call(self.wrapped, "add_ProgressIncremented", value)

    @exception_bridge
    @enforce_parameter_types
    def remove_progress_incremented(
        self: "Self", value: "Callable[[float], None]"
    ) -> None:
        """Method does not return.

        Args:
            value (Callable[[float], None])
        """
        pythonnet_method_call(self.wrapped, "remove_ProgressIncremented", value)

    @exception_bridge
    def abort(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "Abort")

    @exception_bridge
    @enforce_parameter_types
    def continue_with_progress(
        self: "Self",
        status_update: "str",
        perform_analysis: "Callable[[TaskProgress], None]",
    ) -> "TaskProgress":
        """mastapy.TaskProgress

        Args:
            status_update (str)
            perform_analysis (Callable[[mastapy.TaskProgress], None])
        """
        status_update = str(status_update)
        method_result = pythonnet_method_call_overload(
            self.wrapped,
            "ContinueWith",
            [_STRING, _ACTION[_TASK_PROGRESS]],
            status_update if status_update else "",
            perform_analysis,
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @exception_bridge
    @enforce_parameter_types
    def continue_with(
        self: "Self", status_update: "str", perform_analysis: "Callable[..., None]"
    ) -> "TaskProgress":
        """mastapy.TaskProgress

        Args:
            status_update (str)
            perform_analysis (Callable[..., None])
        """
        status_update = str(status_update)
        method_result = pythonnet_method_call_overload(
            self.wrapped,
            "ContinueWith",
            [_STRING, _ACTION],
            status_update if status_update else "",
            perform_analysis,
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @exception_bridge
    def get_all_errors(self: "Self") -> "Iterable[str]":
        """Iterable[str]"""
        return conversion.pn_to_mp_objects_in_iterable(
            pythonnet_method_call(self.wrapped, "GetAllErrors"), str
        )

    @exception_bridge
    @enforce_parameter_types
    def increment_progress(self: "Self", inc: "int" = 1) -> None:
        """Method does not return.

        Args:
            inc (int, optional)
        """
        inc = int(inc)
        pythonnet_method_call(self.wrapped, "IncrementProgress", inc if inc else 0)

    @exception_bridge
    @enforce_parameter_types
    def update_status_with_increment(self: "Self", new_status: "str") -> None:
        """Method does not return.

        Args:
            new_status (str)
        """
        new_status = str(new_status)
        pythonnet_method_call(
            self.wrapped, "UpdateStatusWithIncrement", new_status if new_status else ""
        )

    @exception_bridge
    @enforce_parameter_types
    def add_error(self: "Self", error: "str") -> None:
        """Method does not return.

        Args:
            error (str)
        """
        error = str(error)
        pythonnet_method_call(self.wrapped, "AddError", error if error else "")

    @exception_bridge
    def complete(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "Complete")

    @exception_bridge
    @enforce_parameter_types
    def subdivide(self: "Self", number_of_items: "int") -> "TaskProgress":
        """mastapy.TaskProgress

        Args:
            number_of_items (int)
        """
        number_of_items = int(number_of_items)
        method_result = pythonnet_method_call(
            self.wrapped, "Subdivide", number_of_items if number_of_items else 0
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @exception_bridge
    @enforce_parameter_types
    def subdivide_to_progress_with_error_handling(
        self: "Self", number_of_items: "int"
    ) -> "_7958.TaskProgressWithErrorHandling":
        """mastapy.TaskProgressWithErrorHandling

        Args:
            number_of_items (int)
        """
        number_of_items = int(number_of_items)
        method_result = pythonnet_method_call(
            self.wrapped,
            "SubdivideToProgressWithErrorHandling",
            number_of_items if number_of_items else 0,
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @exception_bridge
    @enforce_parameter_types
    def create_new_task(
        self: "Self",
        title: "str",
        number_of_items: "int",
        show_progress: "bool" = True,
        show_eta: "bool" = False,
        manual_increment: "bool" = False,
        create_task_progress_with_error_handling: "bool" = False,
    ) -> "TaskProgress":
        """mastapy.TaskProgress

        Args:
            title (str)
            number_of_items (int)
            show_progress (bool, optional)
            show_eta (bool, optional)
            manual_increment (bool, optional)
            create_task_progress_with_error_handling (bool, optional)
        """
        title = str(title)
        number_of_items = int(number_of_items)
        show_progress = bool(show_progress)
        show_eta = bool(show_eta)
        manual_increment = bool(manual_increment)
        create_task_progress_with_error_handling = bool(
            create_task_progress_with_error_handling
        )
        method_result = pythonnet_method_call(
            self.wrapped,
            "CreateNewTask",
            title if title else "",
            number_of_items if number_of_items else 0,
            show_progress if show_progress else False,
            show_eta if show_eta else False,
            manual_increment if manual_increment else False,
            create_task_progress_with_error_handling
            if create_task_progress_with_error_handling
            else False,
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @exception_bridge
    def dispose(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "Dispose")

    def __enter__(self: "Self") -> None:
        return self

    def __exit__(
        self: "Self", exception_type: "Any", exception_value: "Any", traceback: "Any"
    ) -> None:
        self.dispose()

    @property
    def cast_to(self: "Self") -> "_Cast_TaskProgress":
        """Cast to another type.

        Returns:
            _Cast_TaskProgress
        """
        return _Cast_TaskProgress(self)



"""ActiveShaftDesignSelectionGroup"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.shafts import _46
from mastapy._private.system_model.part_model.configurations import _2904, _2909
from mastapy._private.system_model.part_model.shaft_model import _2759

_ACTIVE_SHAFT_DESIGN_SELECTION_GROUP = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel.Configurations",
    "ActiveShaftDesignSelectionGroup",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ActiveShaftDesignSelectionGroup")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ActiveShaftDesignSelectionGroup._Cast_ActiveShaftDesignSelectionGroup",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ActiveShaftDesignSelectionGroup",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ActiveShaftDesignSelectionGroup:
    """Special nested class for casting ActiveShaftDesignSelectionGroup to subclasses."""

    __parent__: "ActiveShaftDesignSelectionGroup"

    @property
    def part_detail_configuration(self: "CastSelf") -> "_2909.PartDetailConfiguration":
        return self.__parent__._cast(_2909.PartDetailConfiguration)

    @property
    def active_shaft_design_selection_group(
        self: "CastSelf",
    ) -> "ActiveShaftDesignSelectionGroup":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ActiveShaftDesignSelectionGroup(
    _2909.PartDetailConfiguration[
        _2904.ActiveShaftDesignSelection, _2759.Shaft, _46.SimpleShaftDefinition
    ]
):
    """ActiveShaftDesignSelectionGroup

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ACTIVE_SHAFT_DESIGN_SELECTION_GROUP

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_ActiveShaftDesignSelectionGroup":
        """Cast to another type.

        Returns:
            _Cast_ActiveShaftDesignSelectionGroup
        """
        return _Cast_ActiveShaftDesignSelectionGroup(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.electric_machines.thermal._1488 import (
        AdditionalSliceSpecification,
    )
    from mastapy._private.electric_machines.thermal._1489 import Channel
    from mastapy._private.electric_machines.thermal._1490 import ComponentSetup
    from mastapy._private.electric_machines.thermal._1491 import (
        CoolingChannelForThermalAnalysis,
    )
    from mastapy._private.electric_machines.thermal._1492 import CoolingJacketType
    from mastapy._private.electric_machines.thermal._1493 import EdgeSelector
    from mastapy._private.electric_machines.thermal._1494 import (
        EndWindingCoolingFlowSource,
    )
    from mastapy._private.electric_machines.thermal._1495 import EndWindingLengthSource
    from mastapy._private.electric_machines.thermal._1496 import (
        EndWindingThermalElement,
    )
    from mastapy._private.electric_machines.thermal._1497 import (
        HeatTransferCoefficientCalculationMethod,
    )
    from mastapy._private.electric_machines.thermal._1498 import (
        HousingChannelModificationFactors,
    )
    from mastapy._private.electric_machines.thermal._1499 import HousingFlowDirection
    from mastapy._private.electric_machines.thermal._1500 import InitialInformation
    from mastapy._private.electric_machines.thermal._1501 import InletLocation
    from mastapy._private.electric_machines.thermal._1502 import (
        RegionIDForThermalAnalysis,
    )
    from mastapy._private.electric_machines.thermal._1503 import RotorSetup
    from mastapy._private.electric_machines.thermal._1504 import SliceLengthInformation
    from mastapy._private.electric_machines.thermal._1505 import (
        SliceLengthInformationPerRegion,
    )
    from mastapy._private.electric_machines.thermal._1506 import (
        SliceLengthInformationReporter,
    )
    from mastapy._private.electric_machines.thermal._1507 import StatorSetup
    from mastapy._private.electric_machines.thermal._1508 import ThermalElectricMachine
    from mastapy._private.electric_machines.thermal._1509 import (
        ThermalElectricMachineSetup,
    )
    from mastapy._private.electric_machines.thermal._1510 import ThermalEndcap
    from mastapy._private.electric_machines.thermal._1511 import ThermalEndWinding
    from mastapy._private.electric_machines.thermal._1512 import (
        ThermalEndWindingSurfaceCollection,
    )
    from mastapy._private.electric_machines.thermal._1513 import ThermalHousing
    from mastapy._private.electric_machines.thermal._1514 import ThermalRotor
    from mastapy._private.electric_machines.thermal._1515 import ThermalStator
    from mastapy._private.electric_machines.thermal._1516 import ThermalWindings
    from mastapy._private.electric_machines.thermal._1517 import (
        UserSpecifiedEdgeIndices,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.electric_machines.thermal._1488": ["AdditionalSliceSpecification"],
        "_private.electric_machines.thermal._1489": ["Channel"],
        "_private.electric_machines.thermal._1490": ["ComponentSetup"],
        "_private.electric_machines.thermal._1491": [
            "CoolingChannelForThermalAnalysis"
        ],
        "_private.electric_machines.thermal._1492": ["CoolingJacketType"],
        "_private.electric_machines.thermal._1493": ["EdgeSelector"],
        "_private.electric_machines.thermal._1494": ["EndWindingCoolingFlowSource"],
        "_private.electric_machines.thermal._1495": ["EndWindingLengthSource"],
        "_private.electric_machines.thermal._1496": ["EndWindingThermalElement"],
        "_private.electric_machines.thermal._1497": [
            "HeatTransferCoefficientCalculationMethod"
        ],
        "_private.electric_machines.thermal._1498": [
            "HousingChannelModificationFactors"
        ],
        "_private.electric_machines.thermal._1499": ["HousingFlowDirection"],
        "_private.electric_machines.thermal._1500": ["InitialInformation"],
        "_private.electric_machines.thermal._1501": ["InletLocation"],
        "_private.electric_machines.thermal._1502": ["RegionIDForThermalAnalysis"],
        "_private.electric_machines.thermal._1503": ["RotorSetup"],
        "_private.electric_machines.thermal._1504": ["SliceLengthInformation"],
        "_private.electric_machines.thermal._1505": ["SliceLengthInformationPerRegion"],
        "_private.electric_machines.thermal._1506": ["SliceLengthInformationReporter"],
        "_private.electric_machines.thermal._1507": ["StatorSetup"],
        "_private.electric_machines.thermal._1508": ["ThermalElectricMachine"],
        "_private.electric_machines.thermal._1509": ["ThermalElectricMachineSetup"],
        "_private.electric_machines.thermal._1510": ["ThermalEndcap"],
        "_private.electric_machines.thermal._1511": ["ThermalEndWinding"],
        "_private.electric_machines.thermal._1512": [
            "ThermalEndWindingSurfaceCollection"
        ],
        "_private.electric_machines.thermal._1513": ["ThermalHousing"],
        "_private.electric_machines.thermal._1514": ["ThermalRotor"],
        "_private.electric_machines.thermal._1515": ["ThermalStator"],
        "_private.electric_machines.thermal._1516": ["ThermalWindings"],
        "_private.electric_machines.thermal._1517": ["UserSpecifiedEdgeIndices"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AdditionalSliceSpecification",
    "Channel",
    "ComponentSetup",
    "CoolingChannelForThermalAnalysis",
    "CoolingJacketType",
    "EdgeSelector",
    "EndWindingCoolingFlowSource",
    "EndWindingLengthSource",
    "EndWindingThermalElement",
    "HeatTransferCoefficientCalculationMethod",
    "HousingChannelModificationFactors",
    "HousingFlowDirection",
    "InitialInformation",
    "InletLocation",
    "RegionIDForThermalAnalysis",
    "RotorSetup",
    "SliceLengthInformation",
    "SliceLengthInformationPerRegion",
    "SliceLengthInformationReporter",
    "StatorSetup",
    "ThermalElectricMachine",
    "ThermalElectricMachineSetup",
    "ThermalEndcap",
    "ThermalEndWinding",
    "ThermalEndWindingSurfaceCollection",
    "ThermalHousing",
    "ThermalRotor",
    "ThermalStator",
    "ThermalWindings",
    "UserSpecifiedEdgeIndices",
)



"""CylindricalGearFlankMicroGeometry"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.micro_geometry import _683

_CYLINDRICAL_GEAR_FLANK_MICRO_GEOMETRY = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry",
    "CylindricalGearFlankMicroGeometry",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears.gear_designs.cylindrical import _1144, _1157
    from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import (
        _1229,
        _1232,
        _1239,
        _1241,
        _1246,
        _1250,
        _1254,
        _1264,
        _1268,
        _1271,
        _1272,
    )
    from mastapy._private.math_utility.measured_data import _1782

    Self = TypeVar("Self", bound="CylindricalGearFlankMicroGeometry")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearFlankMicroGeometry._Cast_CylindricalGearFlankMicroGeometry",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearFlankMicroGeometry",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearFlankMicroGeometry:
    """Special nested class for casting CylindricalGearFlankMicroGeometry to subclasses."""

    __parent__: "CylindricalGearFlankMicroGeometry"

    @property
    def flank_micro_geometry(self: "CastSelf") -> "_683.FlankMicroGeometry":
        return self.__parent__._cast(_683.FlankMicroGeometry)

    @property
    def cylindrical_gear_flank_micro_geometry(
        self: "CastSelf",
    ) -> "CylindricalGearFlankMicroGeometry":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CylindricalGearFlankMicroGeometry(_683.FlankMicroGeometry):
    """CylindricalGearFlankMicroGeometry

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_FLANK_MICRO_GEOMETRY

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def micro_geometry_matrix(self: "Self") -> "_1782.GriddedSurfaceAccessor":
        """mastapy.math_utility.measured_data.GriddedSurfaceAccessor"""
        temp = pythonnet_property_get(self.wrapped, "MicroGeometryMatrix")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @micro_geometry_matrix.setter
    @exception_bridge
    @enforce_parameter_types
    def micro_geometry_matrix(
        self: "Self", value: "_1782.GriddedSurfaceAccessor"
    ) -> None:
        pythonnet_property_set(self.wrapped, "MicroGeometryMatrix", value.wrapped)

    @property
    @exception_bridge
    def modified_normal_pressure_angle_due_to_helix_angle_modification_assuming_unmodified_normal_module_and_pressure_angle_modification(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "ModifiedNormalPressureAngleDueToHelixAngleModificationAssumingUnmodifiedNormalModuleAndPressureAngleModification",
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def use_measured_map_data(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseMeasuredMapData")

        if temp is None:
            return False

        return temp

    @use_measured_map_data.setter
    @exception_bridge
    @enforce_parameter_types
    def use_measured_map_data(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseMeasuredMapData",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def bias(self: "Self") -> "_1229.CylindricalGearBiasModification":
        """mastapy.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearBiasModification

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Bias")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def lead_relief(self: "Self") -> "_1232.CylindricalGearLeadModification":
        """mastapy.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearLeadModification

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LeadRelief")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def micro_geometry_map(self: "Self") -> "_1239.CylindricalGearMicroGeometryMap":
        """mastapy.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearMicroGeometryMap

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MicroGeometryMap")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def profile_control_point(
        self: "Self",
    ) -> "_1157.CylindricalGearProfileMeasurement":
        """mastapy.gears.gear_designs.cylindrical.CylindricalGearProfileMeasurement

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ProfileControlPoint")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def profile_relief(self: "Self") -> "_1241.CylindricalGearProfileModification":
        """mastapy.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearProfileModification

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ProfileRelief")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def triangular_end_relief(
        self: "Self",
    ) -> "_1246.CylindricalGearTriangularEndModification":
        """mastapy.gears.gear_designs.cylindrical.micro_geometry.CylindricalGearTriangularEndModification

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TriangularEndRelief")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def lead_form_deviation_points(
        self: "Self",
    ) -> "List[_1250.LeadFormReliefWithDeviation]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.LeadFormReliefWithDeviation]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LeadFormDeviationPoints")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def lead_slope_deviation_points(
        self: "Self",
    ) -> "List[_1254.LeadSlopeReliefWithDeviation]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.LeadSlopeReliefWithDeviation]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LeadSlopeDeviationPoints")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def profile_form_deviation_points(
        self: "Self",
    ) -> "List[_1264.ProfileFormReliefWithDeviation]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.ProfileFormReliefWithDeviation]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ProfileFormDeviationPoints")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def profile_slope_deviation_at_10_percent_face_width(
        self: "Self",
    ) -> "List[_1268.ProfileSlopeReliefWithDeviation]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.ProfileSlopeReliefWithDeviation]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ProfileSlopeDeviationAt10PercentFaceWidth"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def profile_slope_deviation_at_50_percent_face_width(
        self: "Self",
    ) -> "List[_1268.ProfileSlopeReliefWithDeviation]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.ProfileSlopeReliefWithDeviation]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ProfileSlopeDeviationAt50PercentFaceWidth"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def profile_slope_deviation_at_90_percent_face_width(
        self: "Self",
    ) -> "List[_1268.ProfileSlopeReliefWithDeviation]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.ProfileSlopeReliefWithDeviation]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ProfileSlopeDeviationAt90PercentFaceWidth"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def total_lead_relief_points(
        self: "Self",
    ) -> "List[_1271.TotalLeadReliefWithDeviation]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.TotalLeadReliefWithDeviation]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalLeadReliefPoints")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def total_profile_relief_points(
        self: "Self",
    ) -> "List[_1272.TotalProfileReliefWithDeviation]":
        """List[mastapy.gears.gear_designs.cylindrical.micro_geometry.TotalProfileReliefWithDeviation]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TotalProfileReliefPoints")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def gear_design(self: "Self") -> "_1144.CylindricalGearDesign":
        """mastapy.gears.gear_designs.cylindrical.CylindricalGearDesign

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @exception_bridge
    @enforce_parameter_types
    def total_relief(
        self: "Self", face_width: "float", roll_distance: "float"
    ) -> "float":
        """float

        Args:
            face_width (float)
            roll_distance (float)
        """
        face_width = float(face_width)
        roll_distance = float(roll_distance)
        method_result = pythonnet_method_call(
            self.wrapped,
            "TotalRelief",
            face_width if face_width else 0.0,
            roll_distance if roll_distance else 0.0,
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearFlankMicroGeometry":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearFlankMicroGeometry
        """
        return _Cast_CylindricalGearFlankMicroGeometry(self)



"""VerificationOfContactPattern"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_VERIFICATION_OF_CONTACT_PATTERN = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Iso10300", "VerificationOfContactPattern"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="VerificationOfContactPattern")
    CastSelf = TypeVar(
        "CastSelf",
        bound="VerificationOfContactPattern._Cast_VerificationOfContactPattern",
    )


__docformat__ = "restructuredtext en"
__all__ = ("VerificationOfContactPattern",)


class VerificationOfContactPattern(Enum):
    """VerificationOfContactPattern

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _VERIFICATION_OF_CONTACT_PATTERN

    FOR_EACH_GEAR_SET_IN_ITS_HOUSING_UNDER_FULL_LOAD = 0
    FOR_EACH_GEAR_SET_UNDER_LIGHT_TEST_LOAD = 1
    FOR_A_SAMPLE_GEAR_SET_AND_ESTIMATED_FOR_FULL_LOAD = 2


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


VerificationOfContactPattern.__setattr__ = __enum_setattr
VerificationOfContactPattern.__delattr__ = __enum_delattr
